@@ -20,19 +20,15 @@
 
 ######################################################################
 
-VERSION=1.-2.0
+VERSION=1.-2.1
 DEST=hsh-${VERSION}
 SUBDIRS="doc src"
 
 fail() {
-    echo $1
-    echo Aborting
-    exit -1
+    echo "Aborting: $1"
+    exit 1
 }
 
-hg status || fail "hg status failed"
-test -z "`hg status`" || fail 'Cannot make pkg with local changes'
-
 hg archive $DEST
 cd $DEST
 
@@ -42,5 +38,22 @@ for sdir in doc src ; do
     cd -
 done
 
+# Update the code with the correct version
+sed -i "s/'Development Version'/'${VERSION}'/" src/hsh/config.py
+
+# Generate the ChangeLog from the previous tag
+vsuf=${VERSION##*.}
+vpref=${VERSION%.*}
+OLD_VERSION=${vpref}.$(($vsuf - 1))
+hg log -v -r tip:hsh-${OLD_VERSION} > ChangeLog
+
 cd ..
 tar cfz ${DEST}.tar.gz ${DEST}
+
+hg status || fail "hg status failed"
+test -z "`hg status`" || fail 'This tree has local changes'
+
+echo gpg --detach-sign --armor ${DEST}.tar.gz
+echo chmod 644 ${DEST}.tar.gz\*
+echo scp ${DEST}.tar.gz ${DEST}.tar.gz.asc dissent@dl.sv.nongnu.org:/releases/hsh/
+echo hg tag ${DEST}
