@@ -100,9 +100,10 @@ class JobManager(object):
             except ValueError, ve:
                 logging.warn('Invalid directory in jobs dir: %s' % 
                              os.path.join(config.jobs_dir, jd))
-        array_len = max(job_ids) + 1
 
-        self.all_jobs = [None] * array_len
+        # Allocate all_jobs with enough space for everything
+        self.all_jobs = [None] * (max(job_ids + [0]) + 1)
+
         for jd in job_ids:
             self.all_jobs[jd] = os.path.join(config.jobs_dir, str(jd))
 
@@ -319,6 +320,7 @@ class JobOutputThread(threading.Thread):
             self.job.state = "Succeeded"
         else:
             self.job.state = "Failed"
+        self.job.pid = None
         self.job._write_job_state()
         for listener in self.job.listeners:
             listener.on_job_terminate(self.job)
@@ -464,7 +466,6 @@ class ExternalJob(Job):
                                    stdout=subprocess.PIPE,
                                    stderr=subprocess.PIPE)
         self.pid = self.ps.pid
-        # self.ps.stdin.close()
 
         self.stderrthread = JobOutputThread(self, self.ps.stderr, "stderr")
         self.stderrthread.setDaemon(True)
